changeset 9963:737454880ea0 draft

(svn r14118) -Fix(r14104): typos creeping like bugs
author belugas <belugas@openttd.org>
date Thu, 21 Aug 2008 01:42:21 +0000
parents 6d46c3658a0a
children 0f56c3e772cf
files src/vehicle_gui.cpp src/vehicle_gui.h src/vehiclelist.cpp
diffstat 3 files changed, 6 insertions(+), 6 deletions(-) [+]
line wrap: on
line diff
--- a/src/vehicle_gui.cpp
+++ b/src/vehicle_gui.cpp
@@ -800,7 +800,7 @@
 				}
 				break;
 
-			case VLM_WAYPOINT_LIST:
+			case VLW_WAYPOINT_LIST:
 				this->widget[VLW_WIDGET_CAPTION].data = STR_WAYPOINT_VIEWPORT;
 				break;
 
@@ -899,7 +899,7 @@
 				SetDParam(1, this->vscroll.count);
 				break;
 
-			case VLM_WAYPOINT_LIST:
+			case VLW_WAYPOINT_LIST:
 				SetDParam(0, index);
 				break;
 
@@ -1180,7 +1180,7 @@
 void ShowVehicleListWindow(const Waypoint *wp)
 {
 	if (wp == NULL) return;
-	ShowVehicleListWindowLocal(GetTileOwner(wp->xy), VLM_WAYPOINT_LIST, VEH_TRAIN, wp->index);
+	ShowVehicleListWindowLocal(GetTileOwner(wp->xy), VLW_WAYPOINT_LIST, VEH_TRAIN, wp->index);
 }
 
 void ShowVehicleListWindow(const Vehicle *v)
--- a/src/vehicle_gui.h
+++ b/src/vehicle_gui.h
@@ -52,7 +52,7 @@
 	VLW_STATION_LIST  = 2 << 8,
 	VLW_DEPOT_LIST    = 3 << 8,
 	VLW_GROUP_LIST    = 4 << 8,
-	VLM_WAYPOINT_LIST = 5 << 8,
+	VLW_WAYPOINT_LIST = 5 << 8,
 	VLW_MASK          = 0x700,
 };
 
--- a/src/vehiclelist.cpp
+++ b/src/vehiclelist.cpp
@@ -67,7 +67,7 @@
  *      <li>VLW_STANDARD: not used<li>
  *      <li>VLW_DEPOT_LIST: TileIndex of the depot/hangar to make the list for</li>
  *      <li>VLW_GROUP_LIST: index of group to generate a list for</li>
  *      <li>VLM_WAYPOINT_LIST: index of waypoint to generate a list for</li>
  *    </ul>
  * @param window_type The type of window the list is for, using the VLW_ flags in vehicle_gui.h
  */
@@ -123,7 +123,7 @@
 			}
 			break;
 
-		case VLM_WAYPOINT_LIST:
+		case VLW_WAYPOINT_LIST:
 			FOR_ALL_VEHICLES(v) {
 				if (v->type == type && v->IsPrimaryVehicle()) {
 					const Order *order;
@@ -67,7 +67,7 @@
  *      <li>VLW_DEPOT_LIST: TileIndex of the depot/hangar to make the list for</li>
  *      <li>VLW_GROUP_LIST: index of group to generate a list for</li>
- *      <li>VLM_WAYPOINT_LIST: index of waypoint to generate a list for</li>
+ *      <li>VLW_WAYPOINT_LIST: index of waypoint to generate a list for</li>
  *    </ul>
  * @param window_type The type of window the list is for, using the VLW_ flags in vehicle_gui.h